<!---
Navigation specification

See https://oprypin.github.io/mkdocs-literate-nav/
-->
* [Bookshelf](index.md)
* [Getting Started](getting_started.md)
* [Configuration](configuration.md)
* [How-to guides](how-to-guides/index.md)
    * [Analysis](how-to-guides/analysis_with_a_book.py)
    * [Find all books](how-to-guides/find_all_books.py)
    * [Create a new volume](how-to-guides/create_a_new_volume.py)
* [Tutorials](tutorials.md)
* Further background
    * [Explanation](explanation.md)
* [API reference](api/)
* [Development](development.md)
* [Changelog](changelog.md)
